unit FPresentation;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, PythonEngine, PythonGUIInputOutput, PythonAtom,
  ExtCtrls;

type
  TBMode =(bmrun,bmload);

  TFrmPresentation = class(TForm)
    MEM_Script: TRichEdit;
    MEM_Console: TRichEdit;
    PythonEngine: TPythonEngine;
    PythonGUIInputOutput: TPythonGUIInputOutput;
    PYV_DelphiVar: TPythonDelphiVar;
    Panel1: TPanel;
    BtnDoIT: TButton;
    EdText: TEdit;
    UpDown1: TUpDown;
    EdNo: TEdit;
    procedure BtnDoITClick(Sender: TObject);

    procedure FormShow(Sender: TObject);
    procedure PYV_DelphiVarChange(Sender: TObject);

    procedure MEM_ConsoleChange(Sender: TObject);

    procedure FormDestroy(Sender: TObject);
    procedure UpDown1Click(Sender: TObject; Button: TUDBtnType);
    procedure FormCreate(Sender: TObject);

  private

    myAtom : OleVariant;
    fbmode: TBMode;
    Script: TStringList;
    procedure PrepareScript;
    procedure SetBMode(Value:TBMode);
    property bmode:TBMode read fbmode write setbmode;
  public

  end;

var
  FrmPresentation: TFrmPresentation;

implementation

{$R *.DFM}

procedure TFrmPresentation.FormCreate(Sender: TObject);
begin
  Script:=TStringList.Create;
end;

procedure TFrmPresentation.FormShow(Sender: TObject);
begin
  Top:=10;
  Left:=10;
  PrepareScript;
end;

procedure TFrmPresentation.FormDestroy(Sender: TObject);
begin

  Script.free;
end;

procedure TFrmPresentation.BtnDoITClick(Sender: TObject);
var
  i: integer;
begin
  case bmode of
  bmRun:
  begin
    Mem_Console.Clear;
    PythonEngine.ExecStrings(MEM_Script.Lines);
  end;
  bmLoad:
    begin
      Mem_Script.clear;
      for i:=1 to Script.Count-1 do
      begin
        Mem_Script.lines.add(Script[i]) ;
      end;
      bmode:=bmrun;
    end;

  end;
end;

{procedure TFrmPresentation.BTN_DelphiVarIntoAtomClick(Sender: TObject);
var
  value : PPyObject;
begin
  value := PYV_DelphiVar.ValueObject;
  try
    myAtom := getAtom(value);
  finally
    GetPythonEngine.Py_XDecRef(value);
  end;
end;
 }
procedure TFrmPresentation.PYV_DelphiVarChange(Sender: TObject);
begin
  MEM_Console.Lines.Add('delphiVar changed !');
end;
  

procedure TFrmPresentation.MEM_ConsoleChange(Sender: TObject);
begin
  SendMessage(MEM_Console.Handle, EM_SCROLL, SB_LINEDOWN, 0);
end;




procedure TFrmPresentation.PrepareScript;
var

  scriptname: string;
begin
  //loads the script into memory with suffix in EdNo.Text:
  Script.Clear;
  MEM_Console.Lines.Clear;
  MEM_Script.Lines.Clear;
  bmode:=bmload;
  try
    scriptname:='script'+EdNo.Text+'.py';
    Script.LoadfromFile(scriptname);
    BtnDoIt.enabled:=TRUE;
    EdTExt.Font.Color:=clNavy;
    EdText.Text:=copy(Script[0],2,length(Script[0]));

  except
    BtnDoIt.enabled:=FALSE;
    EdTExt.Font.Color:=clRed;
    EdText.Text:=scriptname+' not found';

  end;


end;


procedure TFrmPresentation.UpDown1Click(Sender: TObject;
  Button: TUDBtnType);
begin
  PrepareScript;
end;

procedure TFrmPresentation.SetBMode(Value:TBMode);
begin
  case value of
  bmrun:
    begin
      BtnDoIt.caption:='&Run';
    end;
  bmload:
    begin
       BtnDoIt.caption:='&Load';
    end;
  end;

  fbmode:=value;


end;



end.
